aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/python/TrafficGenerator.py
diff options
context:
space:
mode:
authorMatej Klotton <mklotton@cisco.com>2016-03-24 16:14:20 +0100
committerStefan Kobza <skobza@cisco.com>2016-04-22 15:06:08 +0000
commit8c12ff59f1a5e750151f5eb0e806dcc80e91c3c2 (patch)
treed42ae972c451e4d0714f000ce9262a64ca06848c /resources/libraries/python/TrafficGenerator.py
parent4a7f950c10ca9bcf86e5ccbc3d49a3d7e3cb9809 (diff)
Reformat python libraries.
PEP8 reformat fix typos docstrings reformat Change-Id: Ic48ba4e06490630808b8e2ab1ab0b046ec7eeed7 Signed-off-by: Matej Klotton <mklotton@cisco.com>
Diffstat (limited to 'resources/libraries/python/TrafficGenerator.py')
-rw-r--r--resources/libraries/python/TrafficGenerator.py90
1 files changed, 46 insertions, 44 deletions
diff --git a/resources/libraries/python/TrafficGenerator.py b/resources/libraries/python/TrafficGenerator.py
index c3af0863be..39f8287481 100644
--- a/resources/libraries/python/TrafficGenerator.py
+++ b/resources/libraries/python/TrafficGenerator.py
@@ -15,7 +15,6 @@
from robot.api import logger
from robot.libraries.BuiltIn import BuiltIn
-from robot.api.deco import keyword
from resources.libraries.python.ssh import SSH
from resources.libraries.python.topology import NodeType
@@ -25,8 +24,9 @@ from resources.libraries.python.DropRateSearch import DropRateSearch
__all__ = ['TrafficGenerator', 'TGDropRateSearchImpl']
+
class TGDropRateSearchImpl(DropRateSearch):
- """Drop Rate Search implementation"""
+ """Drop Rate Search implementation."""
def __init__(self):
super(TGDropRateSearchImpl, self).__init__()
@@ -34,19 +34,22 @@ class TGDropRateSearchImpl(DropRateSearch):
def measure_loss(self, rate, frame_size, loss_acceptance,
loss_acceptance_type, traffic_type):
- #we need instance of TrafficGenerator instantiated by Robot Framework
- #to be able to use trex_stateless_remote_exec method
- tg_instance = BuiltIn().get_library_instance('resources.libraries.python.TrafficGenerator')
+ # we need instance of TrafficGenerator instantiated by Robot Framework
+ # to be able to use trex_stateless_remote_exec method
+ tg_instance = BuiltIn().get_library_instance(
+ 'resources.libraries.python.TrafficGenerator')
if tg_instance._node['subtype'] is None:
raise Exception('TG subtype not defined')
elif tg_instance._node['subtype'] == NodeSubTypeTG.TREX:
unit_rate = str(rate) + self.get_rate_type_str()
- tg_instance.trex_stateless_remote_exec(self.get_duration(), unit_rate,
- frame_size, traffic_type)
+ tg_instance.trex_stateless_remote_exec(self.get_duration(),
+ unit_rate, frame_size,
+ traffic_type)
- #TODO:getters for tg_instance and loss_acceptance_type
- logger.trace("comparing: {} < {} ".format(tg_instance._loss, loss_acceptance))
+ # TODO: getters for tg_instance and loss_acceptance_type
+ logger.trace("comparing: {} < {} ".format(tg_instance._loss,
+ loss_acceptance))
if float(tg_instance._loss) > float(loss_acceptance):
return False
else:
@@ -54,10 +57,11 @@ class TGDropRateSearchImpl(DropRateSearch):
else:
raise NotImplementedError("TG subtype not supported")
+
class TrafficGenerator(object):
- """Traffic Generator"""
+ """Traffic Generator."""
- #use one instance of TrafficGenerator for all tests in test suite
+ # use one instance of TrafficGenerator for all tests in test suite
ROBOT_LIBRARY_SCOPE = 'TEST SUITE'
def __init__(self):
@@ -66,24 +70,25 @@ class TrafficGenerator(object):
self._sent = None
self._received = None
self._node = None
- #T-REX interface order mapping
+ # T-REX interface order mapping
self._ifaces_reordered = 0
def initialize_traffic_generator(self, tg_node, tg_if1, tg_if2,
dut1_node, dut1_if1, dut1_if2,
dut2_node, dut2_if1, dut2_if2,
test_type):
- """TG initialization
- :param tg_node: Traffic generator node
- :param tg_if1: TG - name of first interface
- :param tg_if2: TG - name of second interface
- :param dut1_node: DUT1 node
- :param dut1_if1: DUT1 - name of first interface
- :param dut1_if2: DUT1 - name of second interface
- :param dut2_node: DUT2 node
- :param dut2_if1: DUT2 - name of first interface
- :param dut2_if2: DUT2 - name of second interface
- :test_type: 'L2' or 'L3' - src/dst MAC address
+ """TG initialization.
+
+ :param tg_node: Traffic generator node.
+ :param tg_if1: TG - name of first interface.
+ :param tg_if2: TG - name of second interface.
+ :param dut1_node: DUT1 node.
+ :param dut1_if1: DUT1 - name of first interface.
+ :param dut1_if2: DUT1 - name of second interface.
+ :param dut2_node: DUT2 node.
+ :param dut2_if1: DUT2 - name of first interface.
+ :param dut2_if2: DUT2 - name of second interface.
+ :test_type: 'L2' or 'L3' - src/dst MAC address.
:type tg_node: dict
:type tg_if1: str
:type tg_if2: str
@@ -96,7 +101,6 @@ class TrafficGenerator(object):
:type test_type: str
:return: nothing
"""
-
trex_path = "/opt/trex-core-1.91"
topo = Topology()
@@ -172,12 +176,12 @@ class TrafficGenerator(object):
@staticmethod
def teardown_traffic_generator(node):
- """TG teardown
- :param node: Traffic generator node
+ """TG teardown.
+
+ :param node: Traffic generator node.
:type node: dict
:return: nothing
"""
-
if node['type'] != NodeType.TG:
raise Exception('Node type is not a TG')
if node['subtype'] == NodeSubTypeTG.TREX:
@@ -191,11 +195,9 @@ class TrafficGenerator(object):
def trex_stateless_remote_exec(self, duration, rate, framesize,
traffic_type):
- """Execute stateless script on remote node over ssh
+ """Execute stateless script on remote node over ssh.
- :param node: remote node
- :param traffic_type: Traffic profile
- :type node: dict
+ :param traffic_type: Traffic profile.
:type traffic_type: str
"""
ssh = SSH()
@@ -240,7 +242,7 @@ class TrafficGenerator(object):
logger.trace(stdout)
logger.trace(stderr)
- #last line from console output
+ # last line from console output
line = stdout.splitlines()[-1]
self._result = line
@@ -252,21 +254,21 @@ class TrafficGenerator(object):
def send_traffic_on(self, node, duration, rate,
framesize, traffic_type):
- """Send traffic from all configured interfaces on TG
- :param node: Dictionary containing TG information
- :param duration: Duration of test traffic generation in seconds
- :param rate: Offered load per interface (e.g. 1%, 3gbps, 4mpps, ...)
- :param framesize: Frame size (L2) in Bytes
- :param traffic_type: Traffic profile
+ """Send traffic from all configured interfaces on TG.
+
+ :param node: Dictionary containing TG information.
+ :param duration: Duration of test traffic generation in seconds.
+ :param rate: Offered load per interface (e.g. 1%, 3gbps, 4mpps, ...).
+ :param framesize: Frame size (L2) in Bytes.
+ :param traffic_type: Traffic profile.
:type node: dict
:type duration: str
:type rate: str
:type framesize: str
:type traffic_type: str
- :return: TG output
+ :return: TG output.
:rtype: str
"""
-
if node['type'] != NodeType.TG:
raise Exception('Node type is not a TG')
@@ -280,12 +282,12 @@ class TrafficGenerator(object):
return self._result
- def no_traffic_loss_occured(self):
- """Fail is loss occured in traffic run
+ def no_traffic_loss_occurred(self):
+ """Fail is loss occurred in traffic run.
+
:return: nothing
"""
-
if self._loss is None:
raise Exception('The traffic generation has not been issued')
if self._loss != '0':
- raise Exception('Traffic loss occured: {0}'.format(self._loss))
+ raise Exception('Traffic loss occurred: {0}'.format(self._loss))